import * as React from "react";
import { Animated } from "react-native";
import { VideoProperties } from "react-native-video";
import * as PropTypes from "prop-types";
interface Props {
    source: VideoProperties["source"];
    autoStart: boolean;
    loader: React.ReactNode;
    middleControlsBar: React.ReactNode;
    middleControlsBarProps: any;
    bottomControlsBar: React.ReactNode;
    bottomControlsBarProps: any;
    onError(err: any): void;
    onProgress(meta: ProgressStatus): {
        currentTime: number;
        playableDuration: number;
        totalDuration: number;
    };
    onEnd(): void;
}
interface ProgressStatus {
    currentTime: number;
    playableDuration: number;
}
interface State {
    isLoading: boolean;
    showControls: boolean;
    isPaused: boolean;
    currentTime: number;
    totalTime: number;
}
export default class VideoPlayer extends React.PureComponent<Props, State> {
    static propTypes: {
        source: PropTypes.Validator<any>;
        autoStart: PropTypes.Requireable<boolean>;
        loader: PropTypes.Requireable<PropTypes.ReactNodeLike>;
        middleControlsBar: PropTypes.Requireable<((...args: any[]) => any) | PropTypes.ReactElementLike>;
        middleControlsBarProps: PropTypes.Requireable<object>;
        bottomControlsBar: PropTypes.Requireable<((...args: any[]) => any) | PropTypes.ReactElementLike>;
        bottomControlsBarProps: PropTypes.Requireable<object>;
        onError: PropTypes.Requireable<(...args: any[]) => any>;
        onProgress: PropTypes.Requireable<(...args: any[]) => any>;
        onEnd: PropTypes.Requireable<(...args: any[]) => any>;
    };
    static defaultProps: {
        autoStart: boolean;
        onError: () => void;
        onProgress: () => void;
        onEnd: () => void;
    };
    controlsFadeValue: Animated.Value;
    player: {
        seek: (position: number) => void;
    };
    controlsHider: number;
    toggleControls: () => void;
    setPosition: (position: number) => void;
    setNotLoading: () => void;
    setPlaying: () => void;
    setPaused: () => void;
    constructor(props: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: Props, prevState: State): void;
    /**
     * Register a timeout that will hide controls.
     *
     * @param {number} delay In ms
     *
     * @returns {number} Reference to the timeout
     */
    createControlHider(delay?: number): number;
    onLoad(meta: {
        duration: number;
    }): void;
    onProgress(meta: ProgressStatus): void;
    onEnd(): void;
    render(): JSX.Element;
}
export {};
